@@ -7,7 +7,7 @@ import msal
 import requests
 from time import sleep
 
-from .config import (
+from arcl.config import (
     get_config_path,
     get_api_config,
     get_legacy_config_path,
@@ -15,7 +15,7 @@ from .config import (
     get_token_path,
     ARCHIMEDES_CONF_DIR,
 )
-from .token_cache import get_token_cache
+from arcl.token_cache import get_token_cache
 
 AUTH_ACTIONS_LOGIN = "login"
 AUTH_ACTIONS_LOGOUT = "logout"
