@@ -47,3 +47,11 @@ def get_config_path(env):
 
 def get_token_path(env):
     return os.path.join(ARCHIMEDES_CONF_DIR, f"msal-{env}.cache.bin")
+
+
+def get_legacy_config_path():
+    return os.path.join(ARCHIMEDES_CONF_DIR, f"arcl.json")
+
+
+def get_legacy_token_path():
+    return os.path.join(ARCHIMEDES_CONF_DIR, f"msal.cache.bin")
