@@ -4,7 +4,7 @@ from msal_extensions import (
     PersistedTokenCache,
 )
 
-from .config import get_token_path
+from arcl.config import get_token_path
 
 
 def build_persistence(location, fallback_to_plaintext=False):
